@@ -4,14 +4,24 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 use Moose;
 
-with qw(
-  Dist::Zilla::Role::BeforeBuild
-  Dist::Zilla::Role::FileMunger
-  Dist::Zilla::Role::TextTemplate
+with(
+    'Dist::Zilla::Role::BeforeBuild',
+    'Dist::Zilla::Role::FileFinderUser' => {
+        method           => 'found_module_files',
+        finder_arg_names => ['module_finder'],
+        default_finders  => [':InstallModules'],
+    },
+    'Dist::Zilla::Role::FileFinderUser' => {
+        method           => 'found_script_files',
+        finder_arg_names => ['script_finder'],
+        default_finders  => [':PerlExecFiles'],
+    },
+    'Dist::Zilla::Role::FileMunger',
+    'Dist::Zilla::Role::TextTemplate',
 );
 
 sub mvp_multivalue_args { return (qw( skip stopwords travis_ci_ignore_perl )) }
@@ -43,6 +53,7 @@ has _travis_available_perl => (
 
 use Carp;
 use Config::Std { def_sep => q{=} };
+use File::Spec;
 use List::MoreUtils qw(uniq);
 use Path::Tiny;
 
@@ -66,7 +77,15 @@ sub munge_files {
     # But for a release build, the $VERSION of this module changes during the
     # "munge files" phase. We have to recreate the files during the "munge
     # files" phase to add the correct version to the generated files.
-    return if !exists $ENV{DZIL_RELEASING};
+    if ( !exists $ENV{DZIL_RELEASING} ) {
+
+        # We always have to write t/00-load.t during the munge files phase
+        # because this file is not created correctly during the before
+        # build phase because the FileFinderUser isn't initialized that
+        # early
+        $self->_write_file('t/00-load.t');
+        return;
+    }
 
     # This module is part of the Author::SKIRMESS plugin bundle. The bundle
     # is either used to release itself, but also to release other
@@ -113,33 +132,43 @@ sub _write_files {
     my %file_to_skip = map { $_ => 1 } grep { defined && !m{ ^ \s* $ }xsm } @{ $self->skip };
 
   FILE:
-    for my $file ( map { path($_) } sort $self->files() ) {
+    for my $file ( sort $self->files() ) {
         if ( exists $file_to_skip{$file} ) {
             next FILE;
         }
 
-        if ( -e $file ) {
-            $file->remove();
-        }
-        else {
-            # If the file does not yet exist, the basedir might also not
-            # exist. Create it if required.
-            my $parent = $file->parent();
-            if ( !-e $parent ) {
-                $self->log("Creating directory $parent");
-                $parent->mkpath();
-            }
-        }
-
-        $self->log("Generate file $file");
-
-        # write the file to disk
-        $file->spew( $self->file($file) );
+        $self->_write_file($file);
     }
 
     return;
 }
 
+sub _write_file {
+    my ( $self, $file ) = @_;
+
+    $file = path($file);
+
+    if ( -e $file ) {
+        $file->remove();
+    }
+    else {
+        # If the file does not yet exist, the basedir might also not
+        # exist. Create it if required.
+        my $parent = $file->parent();
+        if ( !-e $parent ) {
+            $self->log("Creating directory $parent");
+            $parent->mkpath();
+        }
+    }
+
+    $self->log("Generate file $file");
+
+    # write the file to disk
+    $file->spew( $self->file($file) );
+
+    return;
+}
+
 =pod
 
 =encoding UTF-8
@@ -150,7 +179,7 @@ Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and
 
 =head1 VERSION
 
-Version 0.022
+Version 0.023
 
 =head1 SYNOPSIS
 
@@ -282,7 +311,6 @@ only = 1
 [Modules::ProhibitAutomaticExportation]
 [Modules::ProhibitConditionalUseStatements]
 [Modules::ProhibitEvilModules]
-[Modules::ProhibitExcessMainComplexity]
 [Modules::ProhibitMultiplePackages]
 [Modules::RequireBarewordIncludes]
 [Modules::RequireEndWithOne]
@@ -510,6 +538,86 @@ use warnings;
 
 _TEST_HEADER
 
+=head2 t/00-load.t
+
+Verifies that all modules and perl scripts can be compiled with require_ok
+from L<Test::More|Test::More>.
+
+=cut
+
+    $file{q{t/00-load.t}} = sub {
+        my ($self) = @_;
+
+        my %use_lib_args = (
+            lib  => undef,
+            q{.} => undef,
+        );
+
+        my @modules;
+      MODULE:
+        for my $module ( map { $_->name } @{ $self->found_module_files() } ) {
+            next MODULE if $module =~ m{ [.] pod $}xsm;
+
+            my @dirs = File::Spec->splitdir($module);
+            if ( $dirs[0] eq 'lib' && $dirs[-1] =~ s{ [.] pm $ }{}xsm ) {
+                shift @dirs;
+                push @modules, join q{::}, @dirs;
+                $use_lib_args{lib} = 1;
+                next MODULE;
+            }
+
+            $use_lib_args{q{.}} = 1;
+            push @modules, $module;
+        }
+
+        my @scripts = map { $_->name } @{ $self->found_script_files() };
+        if (@scripts) {
+            $use_lib_args{q{.}} = 1;
+        }
+
+        my $content = $test_header . <<'T_OO_LOAD_T';
+use Test::More;
+
+T_OO_LOAD_T
+
+        if ( !@scripts && !@modules ) {
+            $content .= qq{BAIL_OUT("No files found in distribution");\n};
+
+            return $content;
+        }
+
+        $content .= 'use lib qw(';
+        if ( defined $use_lib_args{lib} ) {
+            if ( defined $use_lib_args{q{.}} ) {
+                $content .= 'lib .';
+            }
+            else {
+                $content .= 'lib';
+            }
+        }
+        else {
+            $content .= q{.};
+        }
+        $content .= ");\n\n";
+
+        $content .= "my \@modules = qw(\n";
+
+        for my $module ( @modules, @scripts ) {
+            $content .= "  $module\n";
+        }
+        $content .= <<'T_OO_LOAD_T';
+);
+
+plan tests => scalar @modules;
+
+for my $module (@modules) {
+    require_ok($module) || BAIL_OUT();
+}
+T_OO_LOAD_T
+
+        return $content;
+    };
+
 =head2 xt/author/clean-namespaces.t
 
 L<Test::CleanNamespaces|Test::CleanNamespaces> author test.
